"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.showWarningDialog = exports.showErrorDialog = exports.showDialog = void 0;
const electron_1 = require("electron");
const locale = __importStar(require("../locale"));
const showDialog = (message, title, type) => {
    const options = {
        message,
        title,
        type,
    };
    electron_1.dialog.showMessageBoxSync(options);
};
exports.showDialog = showDialog;
const showErrorDialog = (message) => {
    (0, exports.showDialog)(message, locale.getText('promptError'), 'error');
};
exports.showErrorDialog = showErrorDialog;
const showWarningDialog = (message) => {
    const options = {
        buttons: [locale.getText('promptOK')],
        message,
        title: locale.getText('promptWarning'),
        type: 'warning',
    };
    electron_1.dialog.showMessageBoxSync(options);
};
exports.showWarningDialog = showWarningDialog;
//# sourceMappingURL=showDialog.js.map