"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubIcon = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const SVGIcon_1 = require("../SVGIcon");
const GitHubIcon = (props) => ((0, jsx_runtime_1.jsx)(SVGIcon_1.SVGIcon, Object.assign({ realWidth: 16, realHeight: 16 }, props, { children: (0, jsx_runtime_1.jsx)("path", { d: "M8 .5a7.5 7.5 0 0 0-2.37 14.616c.375.07.511-.163.511-.361 0-.178-.006-.65-.01-1.276-2.086.453-2.526-1.005-2.526-1.005-.341-.867-.833-1.097-.833-1.097-.68-.465.052-.456.052-.456.752.053 1.148.773 1.148.773.67 1.146 1.755.815 2.183.623.068-.485.262-.815.476-1.003-1.665-.189-3.416-.832-3.416-3.706a2.9 2.9 0 0 1 .772-2.013c-.077-.19-.335-.952.073-1.985 0 0 .63-.201 2.063.77A7.183 7.183 0 0 1 8 4.126a7.194 7.194 0 0 1 1.878.252c1.432-.97 2.06-.769 2.06-.769.41 1.033.152 1.796.075 1.985a2.9 2.9 0 0 1 .771 2.013c0 2.881-1.754 3.515-3.424 3.7.269.232.509.69.509 1.39 0 1.002-.01 1.81-.01 2.057 0 .2.135.434.516.36A7.5 7.5 0 0 0 8 .5" }) })));
exports.GitHubIcon = GitHubIcon;
