"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Content = exports.contentStyle = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const sizes_1 = require("./sizes");
const contentStyle = _ => ({
    display: 'flex',
    flexDirection: 'column',
    flexGrow: 1,
    padding: `0 ${sizes_1.GUTTER}px`,
});
exports.contentStyle = contentStyle;
const Content = (props) => (0, jsx_runtime_1.jsx)("div", Object.assign({ css: (0, exports.contentStyle)(props) }, props));
exports.Content = Content;
