"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.gatherLogs = exports.getLogFilenames = exports.logDir = void 0;
const electron_1 = require("electron");
const fs = __importStar(require("fs-extra"));
const globby_1 = __importDefault(require("globby"));
const path = __importStar(require("path"));
const getLogger_1 = require("../logging/getLogger");
const logger = (0, getLogger_1.getLogger)(path.basename(__filename));
exports.logDir = path.join(electron_1.app.getPath('userData'), 'logs');
function getLogFilenames(base = exports.logDir, absolute = false) {
    return globby_1.default.sync('**/*.{log,old}', { absolute, cwd: base, followSymbolicLinks: false, onlyFiles: true });
}
exports.getLogFilenames = getLogFilenames;
function gatherLogs() {
    return __awaiter(this, void 0, void 0, function* () {
        const logFiles = {};
        const relativeFilePaths = getLogFilenames();
        for (const relativeFilePath of relativeFilePaths) {
            const resolvedPath = path.join(exports.logDir, relativeFilePath);
            try {
                const fileContent = yield fs.readFile(resolvedPath);
                logFiles[relativeFilePath] = fileContent;
            }
            catch (error) {
                logger.error(error);
            }
        }
        return logFiles;
    });
}
exports.gatherLogs = gatherLogs;
//# sourceMappingURL=loggerUtils.js.map