"use strict";
/*
 * Wire
 * Copyright (C) 2019 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimeInMillis = void 0;
var TimeInMillis;
(function (TimeInMillis) {
    TimeInMillis[TimeInMillis["SECOND"] = 1000] = "SECOND";
    TimeInMillis[TimeInMillis["MINUTE"] = 60000] = "MINUTE";
    TimeInMillis[TimeInMillis["HOUR"] = 3600000] = "HOUR";
    TimeInMillis[TimeInMillis["DAY"] = 86400000] = "DAY";
    TimeInMillis[TimeInMillis["WEEK"] = 604800000] = "WEEK";
    TimeInMillis[TimeInMillis["YEAR"] = 31536000000] = "YEAR";
})(TimeInMillis = exports.TimeInMillis || (exports.TimeInMillis = {}));
//# sourceMappingURL=TimeUtil.js.map