"use strict";
/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
__exportStar(require("./AddPeopleIcon"), exports);
__exportStar(require("./ArchiveIcon"), exports);
__exportStar(require("./ArrowIcon"), exports);
__exportStar(require("./AttachmentIcon"), exports);
__exportStar(require("./AudioVideoIcon"), exports);
__exportStar(require("./BlockIcon"), exports);
__exportStar(require("./CopyIcon"), exports);
__exportStar(require("./CallIcon"), exports);
__exportStar(require("./CameraIcon"), exports);
__exportStar(require("./CamIcon"), exports);
__exportStar(require("./CheckIcon"), exports);
__exportStar(require("./CheckRoundIcon"), exports);
__exportStar(require("./ChevronIcon"), exports);
__exportStar(require("./CloseIcon"), exports);
__exportStar(require("./DeviceIcon"), exports);
__exportStar(require("./DownloadIcon"), exports);
__exportStar(require("./EditDocumentIcon"), exports);
__exportStar(require("./EditIcon"), exports);
__exportStar(require("./EnterIcon"), exports);
__exportStar(require("./ErrorIcon"), exports);
__exportStar(require("./FileIcon"), exports);
__exportStar(require("./GifIcon"), exports);
__exportStar(require("./GroupIcon"), exports);
__exportStar(require("./HangupIcon"), exports);
__exportStar(require("./HideIcon"), exports);
__exportStar(require("./ImageIcon"), exports);
__exportStar(require("./SupportIcon"), exports);
__exportStar(require("./InfoIcon"), exports);
__exportStar(require("./InviteIcon"), exports);
__exportStar(require("./LeaveIcon"), exports);
__exportStar(require("./LinkIcon"), exports);
__exportStar(require("./ListIcon"), exports);
__exportStar(require("./LockIcon"), exports);
__exportStar(require("./MessageIcon"), exports);
__exportStar(require("./MinusIcon"), exports);
__exportStar(require("./MoreIcon"), exports);
__exportStar(require("./MuteIcon"), exports);
__exportStar(require("./NotificationIcon"), exports);
__exportStar(require("./NotificationOffIcon"), exports);
__exportStar(require("./OptionsIcon"), exports);
__exportStar(require("./GridIcon"), exports);
__exportStar(require("./PeopleIcon"), exports);
__exportStar(require("./PingIcon"), exports);
__exportStar(require("./PlaneIcon"), exports);
__exportStar(require("./PlusIcon"), exports);
__exportStar(require("./ProfileIcon"), exports);
__exportStar(require("./RecordIcon"), exports);
__exportStar(require("./RecordBoldIcon"), exports);
__exportStar(require("./RecordPendingIcon"), exports);
__exportStar(require("./ReloadIcon"), exports);
__exportStar(require("./ScreenshareIcon"), exports);
__exportStar(require("./SearchIcon"), exports);
__exportStar(require("./ServicesIcon"), exports);
__exportStar(require("./SettingsIcon"), exports);
__exportStar(require("./ShowIcon"), exports);
__exportStar(require("./SignIcon"), exports);
__exportStar(require("./SpeakerIcon"), exports);
__exportStar(require("./TeamIcon"), exports);
__exportStar(require("./TimedIcon"), exports);
__exportStar(require("./TrashIcon"), exports);
__exportStar(require("./TrashCrossIcon"), exports);
__exportStar(require("./TriangleIcon"), exports);
__exportStar(require("./UploadIcon"), exports);
__exportStar(require("./WireIcon"), exports);
// Brand Icons
__exportStar(require("./Brand/AndroidIcon"), exports);
__exportStar(require("./Brand/AppleIcon"), exports);
__exportStar(require("./Brand/ChromeIcon"), exports);
__exportStar(require("./Brand/FacebookIcon"), exports);
__exportStar(require("./Brand/GitHubIcon"), exports);
__exportStar(require("./Brand/LinkedInIcon"), exports);
__exportStar(require("./Brand/LinuxIcon"), exports);
__exportStar(require("./Brand/MicrosoftIcon"), exports);
__exportStar(require("./Brand/TwitterIcon"), exports);
