"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FlexBox = exports.filterFlexBoxProps = exports.flexBoxStyle = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2017 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const React = __importStar(require("react"));
const util_1 = require("../util");
const flexBoxStyle = ({ align = 'flex-start', column = false, justify = 'flex-start', flexWrap = 'nowrap', }) => ({
    alignItems: align,
    display: 'flex',
    flexDirection: column ? 'column' : 'row',
    flexWrap: flexWrap,
    justifyContent: justify,
});
exports.flexBoxStyle = flexBoxStyle;
const filterFlexBoxProps = (props) => (0, util_1.filterProps)(props, ['align', 'column', 'justify', 'flexWrap']);
exports.filterFlexBoxProps = filterFlexBoxProps;
exports.FlexBox = React.forwardRef((props, ref) => ((0, jsx_runtime_1.jsx)("div", Object.assign({ ref: ref, css: (0, exports.flexBoxStyle)(props) }, (0, exports.filterFlexBoxProps)(props)))));
exports.FlexBox.displayName = 'FlexBox';
