"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuScrollableItems = exports.menuScrollableItemsStyle = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const mediaQueries_1 = require("../../mediaQueries");
const menuScrollableItemsStyle = _ => ({
    alignItems: 'center',
    alignSelf: 'center',
    display: 'flex',
    [mediaQueries_1.media[mediaQueries_1.QueryKeys.TABLET_DOWN]]: {
        alignItems: 'center',
        flexDirection: 'column',
        margin: 'auto',
    },
});
exports.menuScrollableItemsStyle = menuScrollableItemsStyle;
const MenuScrollableItems = (props) => ((0, jsx_runtime_1.jsx)("div", Object.assign({ css: (0, exports.menuScrollableItemsStyle)(props) }, props)));
exports.MenuScrollableItems = MenuScrollableItems;
