"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TriangleIcon = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const SVGIcon_1 = require("./SVGIcon");
const rotation = {
    down: 0,
    left: 90,
    up: 180,
    right: 270,
};
const TriangleIcon = (_a) => {
    var { direction = 'down' } = _a, props = __rest(_a, ["direction"]);
    return ((0, jsx_runtime_1.jsx)(SVGIcon_1.SVGIcon, Object.assign({ realWidth: 8, realHeight: 8 }, props, { children: (0, jsx_runtime_1.jsx)("path", { transform: `rotate(${rotation[direction]} 4 4)`, fillRule: "evenodd", d: "M0 2h8L4 7" }) })));
};
exports.TriangleIcon = TriangleIcon;
