"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnterIcon = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2020 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const SVGIcon_1 = require("./SVGIcon");
const EnterIcon = (props) => ((0, jsx_runtime_1.jsx)(SVGIcon_1.SVGIcon, Object.assign({ realWidth: 24, realHeight: 18 }, props, { children: (0, jsx_runtime_1.jsx)("path", { d: "M11.643 7l-1.5 1.4 2.786 2.6H2v2h10.929l-2.786 2.6 1.5 1.4L17 12l-5.357-5zM21.8 19H13v2h8.8c1.21 0 2.2-.9 2.2-2V5c0-1.1-.99-2-2.2-2H13v2h8.8v14z" }) })));
exports.EnterIcon = EnterIcon;
