"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Title = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const Text_1 = require("./Text");
const Identity_1 = require("../Identity");
const titleStyle = (theme, _a) => {
    var { block = true, center = true, fontSize = ' 2rem', color = Identity_1.COLOR.GRAY, bold = true } = _a, props = __rest(_a, ["block", "center", "fontSize", "color", "bold"]);
    return (Object.assign(Object.assign({}, (0, Text_1.textStyle)(theme, Object.assign({ block, bold, center, color, fontSize }, props))), { marginBottom: '8px' }));
};
const Title = (props) => ((0, jsx_runtime_1.jsx)("div", Object.assign({ css: (theme) => titleStyle(theme, props) }, (0, Text_1.filterTextProps)(props))));
exports.Title = Title;
