"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Header = exports.headerStyle = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const headerStyle = _ => ({
    alignItems: 'center',
    display: 'flex',
    height: '64px',
    justifyContent: 'space-between',
});
exports.headerStyle = headerStyle;
const Header = (props) => (0, jsx_runtime_1.jsx)("header", Object.assign({ css: (0, exports.headerStyle)(props) }, props));
exports.Header = Header;
