"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputSubmitCombo = exports.INPUT_SUBMIT_COMBO_CLASSNAME = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const Input_1 = require("./Input");
const Identity_1 = require("../Identity");
exports.INPUT_SUBMIT_COMBO_CLASSNAME = 'inputSubmitCombo';
const InputSubmitCombo = (_a) => {
    var { children } = _a, props = __rest(_a, ["children"]);
    return ((0, jsx_runtime_1.jsx)("div", Object.assign({ className: exports.INPUT_SUBMIT_COMBO_CLASSNAME, css: (theme) => (Object.assign(Object.assign({}, (0, Input_1.inputStyle)(theme, props)), { '&:focus-within': {
                boxShadow: `0 0 0 1px ${Identity_1.COLOR_V2.BLUE}`,
            }, [`.${Input_1.INPUT_GROUP}`]: {
                flexGrow: 1,
            }, [`.${Input_1.INPUT_CLASSNAME}`]: {
                '&:focus, &:invalid:not(:focus)': {
                    boxShadow: 'none',
                },
                boxShadow: 'none',
                margin: '0 8px 0 0',
                padding: '0 0 0 16px',
            }, alignItems: 'center', display: 'flex', height: '49px', justifyContent: 'space-between', marginBottom: '4px', paddingLeft: 0 })) }, props, { children: children })));
};
exports.InputSubmitCombo = InputSubmitCombo;
