"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enable = exports.initialize = void 0;
var server_1 = require("./server");
Object.defineProperty(exports, "initialize", { enumerable: true, get: function () { return server_1.initialize; } });
Object.defineProperty(exports, "enable", { enumerable: true, get: function () { return server_1.enable; } });
