/*
 * Wire
 * Copyright (C) 2021 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */

syntax = "proto2";

package mls;

option java_package = "com.wire.messages";
option java_outer_classname = "Mls";
option optimize_for = LITE_RUNTIME;

enum GroupInfoType {
    PUBLIC_GROUP_STATE = 1;
    GROUP_INFO         = 2;
    GROUP_INFO_JWE     = 3;
};

enum RatchetTreeType {
    FULL      = 1;
    DELTA     = 2;
    REFERENCE = 3;
};

message GroupInfoBundle {
    required GroupInfoType group_info_type           = 1;
    required RatchetTreeType ratchet_tree_type       = 2;
    required bytes group_info                        = 3;
}

message CommitBundle {
    required bytes commit                      = 1; // MlsMessage containing an MlsPlaintext Commit
    optional bytes welcome                     = 2; // MlsMessage containing a Welcome
    required GroupInfoBundle group_info_bundle = 3;
}
