/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */

html {
  width: 100%;
  height: 100%;
}

body {
  width: 100%;
  height: 100%;
  margin: 0;
  padding: 0;
  color: #000;
  background-color: #ececec;
  display: flex;
  justify-content: center;
  align-items: center;
  font-family: -apple-system, '.SFNSText-Regular', 'Helvetica Neue', 'Segoe UI', Arial, sans-serif;
  font-size: 11px;
  text-align: center;
  cursor: default;
  user-select: none;
}

.copy {
  user-select: all;
}

h1 {
  font-size: 16px;
}

p {
  margin: 0 0 4px;
}

img {
  width: 64px;
  height: 64px;
}
