"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MenuContent = exports.menuContentStyle = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const util_1 = require("../../util");
const Content_1 = require("../Content");
const menuContentStyle = props => (Object.assign(Object.assign({}, (0, Content_1.contentStyle)(props)), { alignItems: 'center', display: 'grid', gridColumnGap: '8px', gridTemplateColumns: '1fr auto 1fr', height: '64px', justifyContent: 'space-between', left: props.open ? 0 : undefined, position: props.open ? 'fixed' : undefined, width: props.open ? '100%' : undefined, zIndex: props.open ? 10000 : undefined }));
exports.menuContentStyle = menuContentStyle;
const filterMenuContentProps = (props) => (0, util_1.filterProps)(props, ['open']);
const MenuContent = (props) => ((0, jsx_runtime_1.jsx)("div", Object.assign({ css: (0, exports.menuContentStyle)(props) }, filterMenuContentProps(props))));
exports.MenuContent = MenuContent;
