"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TwitterIcon = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const SVGIcon_1 = require("../SVGIcon");
const TwitterIcon = (props) => ((0, jsx_runtime_1.jsx)(SVGIcon_1.SVGIcon, Object.assign({ realWidth: 16, realHeight: 16 }, props, { children: (0, jsx_runtime_1.jsx)("path", { d: "M13.73 3.687a3.079 3.079 0 0 0 1.353-1.71 6.27 6.27 0 0 1-1.944.75 3.14 3.14 0 0 0-2.257-.977 3.075 3.075 0 0 0-3.073 3.089c0 .244.017.488.07.715-2.553-.14-4.81-1.309-6.337-3.176-.26.454-.417.925-.417 1.5a3.08 3.08 0 0 0 1.372 2.566 3.118 3.118 0 0 1-1.39-.384c0 1.536 1.06 2.792 2.466 3.071a3.17 3.17 0 0 1-1.389.053c.382 1.221 1.528 2.129 2.865 2.146-1.042.838-2.379 1.466-3.82 1.466-.243 0-.486-.018-.729-.052C1.854 13.616 3.486 14 5.222 14c5.66 0 8.75-4.712 8.75-8.795v-.401A6.391 6.391 0 0 0 15.5 3.198a6.06 6.06 0 0 1-1.77.489z" }) })));
exports.TwitterIcon = TwitterIcon;
