"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FacebookIcon = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const SVGIcon_1 = require("../SVGIcon");
const FacebookIcon = (props) => ((0, jsx_runtime_1.jsx)(SVGIcon_1.SVGIcon, Object.assign({ realWidth: 16, realHeight: 16 }, props, { children: (0, jsx_runtime_1.jsx)("path", { d: "M14.227 1H1.773A.773.773 0 0 0 1 1.773v12.454c0 .427.346.773.773.773h6.705V9.578H6.653V7.466h1.825V5.907c0-1.808 1.104-2.793 2.717-2.793a14.8 14.8 0 0 1 1.63.084v1.89h-1.118c-.877 0-1.047.417-1.047 1.029v1.349h2.092l-.272 2.112h-1.82V15h3.567a.773.773 0 0 0 .773-.773V1.773A.773.773 0 0 0 14.227 1" }) })));
exports.FacebookIcon = FacebookIcon;
