"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecordBoldIcon = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2020 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const SVGIcon_1 = require("./SVGIcon");
const Identity_1 = require("../Identity");
const RecordBoldIcon = (_a) => {
    var { color = Identity_1.COLOR.TEXT } = _a, props = __rest(_a, ["color"]);
    return ((0, jsx_runtime_1.jsxs)(SVGIcon_1.SVGIcon, Object.assign({ realWidth: 20, realHeight: 16, color: color }, props, { children: [(0, jsx_runtime_1.jsx)("path", { fill: "none", d: "M0 0H24V24H0z" }), (0, jsx_runtime_1.jsx)("circle", { fill: "none", cx: "10", cy: "10", r: "9", css: { stroke: color }, strokeWidth: "2" }), (0, jsx_runtime_1.jsx)("circle", { cx: "10", cy: "10", r: "4", css: {
                    fill: color,
                    stroke: color,
                }, strokeWidth: "2" })] })));
};
exports.RecordBoldIcon = RecordBoldIcon;
