"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Line = exports.lineStyle = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const Identity_1 = require("../Identity");
const sizes_1 = require("../Layout/sizes");
const lineStyle = ({ color = Identity_1.COLOR.GRAY_LIGHTEN_72 }) => ({
    border: 'none',
    borderBottom: `1px solid ${color}`,
    marginBottom: `${sizes_1.GUTTER}px`,
    marginTop: `${sizes_1.GUTTER}px`,
});
exports.lineStyle = lineStyle;
const Line = (props) => (0, jsx_runtime_1.jsx)("hr", Object.assign({ css: (0, exports.lineStyle)(props) }, props));
exports.Line = Line;
