"use strict";
/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.GUTTER = exports.STEP = exports.WIDTH = void 0;
exports.WIDTH = {
    TINY: 320,
    MOBILE: 480,
    MOBILE_MAX: 639,
    TABLET_MIN: 640,
    TABLET_MAX: 919,
    DESKTOP_MIN: 920,
    DESKTOP_MAX: 1199,
    DESKTOP_XL_MIN: 1200,
    DESKTOP_XL_MAX: 1600,
};
exports.STEP = 8;
exports.GUTTER = exports.STEP + exports.STEP;
