"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Box = exports.boxStyle = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const Identity_1 = require("../Identity");
const boxStyle = _ => ({
    border: `2px solid ${Identity_1.COLOR.GRAY_LIGHTEN_72}`,
    borderRadius: '8px',
    padding: '16px 32px',
});
exports.boxStyle = boxStyle;
const Box = (props) => (0, jsx_runtime_1.jsx)("div", Object.assign({ css: (0, exports.boxStyle)(props) }, props));
exports.Box = Box;
