"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputBlock = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const Input_1 = require("./Input");
const InputSubmitCombo_1 = require("./InputSubmitCombo");
const Identity_1 = require("../Identity");
const inputBlockStyle = _ => ({
    backgroundColor: Identity_1.COLOR.GRAY_LIGHTEN_88,
    borderRadius: '4px',
    boxShadow: `inset 16px 16px 0 ${Identity_1.COLOR.WHITE}, inset -16px -16px 0 ${Identity_1.COLOR.WHITE}`,
    marginBottom: '16px',
    [`.${Input_1.INPUT_CLASSNAME}, .${InputSubmitCombo_1.INPUT_SUBMIT_COMBO_CLASSNAME}`]: {
        marginBottom: '1px !important',
        marginTop: '0 !important',
    },
    [`.${Input_1.INPUT_GROUP}`]: {
        marginBottom: 0,
    },
});
const InputBlock = (props) => (0, jsx_runtime_1.jsx)("div", Object.assign({ css: inputBlockStyle(props) }, props));
exports.InputBlock = InputBlock;
