"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Form = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
const Form = (props) => ((0, jsx_runtime_1.jsx)("form", Object.assign({ css: {
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'space-between',
        marginBottom: 0,
        width: '100%',
    } }, props)));
exports.Form = Form;
