"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EditIcon = void 0;
const jsx_runtime_1 = require("@emotion/react/jsx-runtime");
/*
 * Wire
 * Copyright (C) 2018 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */
const SVGIcon_1 = require("./SVGIcon");
const EditIcon = (props) => ((0, jsx_runtime_1.jsx)(SVGIcon_1.SVGIcon, Object.assign({ realWidth: 16, realHeight: 16 }, props, { children: (0, jsx_runtime_1.jsx)("path", { d: "M14.553 4.846l.746-.746a2.4 2.4 0 0 0-.007-3.392A2.392 2.392 0 0 0 11.9.701l-.746.746 3.399 3.399zm-.707.707L4.248 15.15 0 16l.85-4.248 9.597-9.598 3.399 3.399zM4 13.6L2 14l.4-2L4 13.6z" }) })));
exports.EditIcon = EditIcon;
