"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OriginValidator = void 0;
const url_1 = require("url");
exports.OriginValidator = {
    isMatchingHost(urlString, baseUrl) {
        return new url_1.URL(urlString).host === new url_1.URL(baseUrl).host;
    },
};
//# sourceMappingURL=OriginValidator.js.map